#!/bin/bash

# Maintainer		: Pierrick Le Brun <akuna at free.fr>
# source location  	: http://zenlive.linuxish.net/people/akuna/zenlive-tools/${pkgname}/${pkgver}/source/
# last revised      : 03.05.2009

softname='zeninstaller'
softversion='0.9.9.2'
packageversion='60.1'
arch='noarch'

prefix=/usr

#
# log
#
(

# parameters needed for the build process
buildir=$(pwd)
srcpkg="$buildir/$softname-$softversion.tar.gz"
src="$buildir/$softname-$softversion"
package="$softname-$softversion-$arch-$packageversion"
dest="$buildir/$package"
source=http://zenlive.linuxish.net/people/akuna/zenlive-tools/${softname}/${softversion}/source/${softname}-${softversion}.tar.gz

# prepare the build result directory
rm -rf $dest
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/usr/doc/$softname-$softversion
mkdir -p $dest/usr/src/$softname-$softversion

# Slack-desc
cat <<EOF > $dest/install/slack-desc
zeninstaller: Zen Installer
zeninstaller: 
zeninstaller: A ZenLive tool
zeninstaller:
zeninstaller: Zen Installer executed from Zenwalk Live will perform a standard
zeninstaller: Zenwalk installation onto your hard drive while Zen Installer
zeninstaller: executed from a cloned LiveCD --created with Live Clone-- will
zeninstaller: perform a cloned installation of that LiveCD.
zeninstaller: 
zeninstaller:
zeninstaller:
EOF

#
# check if source is present
#
cd $buildir
if [ -f $softname-$softversion.tar.gz ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c --no-check-certificate $source
fi

# extract the source code
cd $buildir
tar xzvf $srcpkg
cd $src

# Populate the package
cp -rf usr $dest
cp -f *txt $dest/usr/doc/$softname-$softversion

# Strip Executables
( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

# ZenBuild
cp $buildir/build-$softname.sh $dest/$prefix/src/$softname-$softversion

# set target permissions
chown -R root:root $dest

cd $dest
find . -perm 664 -exec chmod 644 {} \;
find . -perm 640 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;
find . -type d -exec chmod 755 {} \;

# real packaging work:
cd $dest
makepkg -l y -c n $dest.tgz

# computes the md5sum signature for the package
cd $buildir
md5sum $package.tgz > $package.md5

# dep file
# echo -e "dependency1,dependency2" > $package.dep

#
# erase source
#
#~ rm -rf $src
#~ rm -rf $dest

#
# generate source file
#
echo http://zenlive.linuxish.net/people/akuna/zenlive-tools/${softname}/${softversion}/source/build-zeninstaller.sh > $package.src
echo $source >>$package.src

#
# log
#
) 2>&1 | tee "$softname-$softversion-build.log"
